==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRecordDescriptionMetadata } from "./WebGroupByRecordDescriptionMetadata";
import { WebGroupByRowSelectorTemplateDetailsDescription } from "./WebGroupByRowSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
var WebGroupByRowSelectorTemplateDetailsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata, _super);
    function WebGroupByRowSelectorTemplateDetailsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.b = function (a) {
        if (WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a == null) {
            WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.c(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
        if (a.j(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
        WebGroupByRecordDescriptionMetadata.d(a);
    };
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRowSelectorTemplateDetails");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("SelectedCount", "Number:double");
        a.item("TotalCount", "Number:double");
        a.item("GroupRow", "ExportedType:WebGroupByRecord");
    };
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.d = function (a) {
        WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.b(a);
        a.aa("WebGroupByRowSelectorTemplateDetails", function () { return new WebGroupByRowSelectorTemplateDetailsDescription(); });
        a.z("WebGroupByRowSelectorTemplateDetails", WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata, 'WebGroupByRowSelectorTemplateDetailsDescriptionMetadata');
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebGroupByRowSelectorTemplateDetailsDescriptionMetadata;
}(Base));
export { WebGroupByRowSelectorTemplateDetailsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRecordDescriptionMetadata } from "./WebGroupByRecordDescriptionMetadata";
import { WebGroupByRowSelectorTemplateDetailsDescription } from "./WebGroupByRowSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
var WebGroupByRowSelectorTemplateDetailsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata, _super);
    function WebGroupByRowSelectorTemplateDetailsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.b = function (a) {
        if (WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a == null) {
            WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.c(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
        if (a.k(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
        WebGroupByRecordDescriptionMetadata.d(a);
    };
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRowSelectorTemplateDetails");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("SelectedCount", "Number:double");
        a.item("TotalCount", "Number:double");
        a.item("GroupRow", "ExportedType:WebGroupByRecord");
    };
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.d = function (a) {
        WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.b(a);
        a.ac("WebGroupByRowSelectorTemplateDetails", function () { return new WebGroupByRowSelectorTemplateDetailsDescription(); });
        a.ab("WebGroupByRowSelectorTemplateDetails", WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata, 'WebGroupByRowSelectorTemplateDetailsDescriptionMetadata');
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebGroupByRowSelectorTemplateDetailsDescriptionMetadata;
}(Base));
export { WebGroupByRowSelectorTemplateDetailsDescriptionMetadata };
